@@ -127,6 +127,7 @@ parseopts (int argc, char **restrict argv, struct law *restrict l)
     l->verbosity = 0;
     l->locks = true;
     l->kingdom = 0;		// --many-fs disabled
+    l->workaround = true;
     l->xattr = 1;
   }
   /* Like the manpage said .. */
@@ -151,11 +152,12 @@ parseopts (int argc, char **restrict argv, struct law *restrict l)
 	{"small-tolerance", required_argument, NULL, 't'},
 	{"big-tolerance", required_argument, NULL, 'T'},
 	{"version", no_argument, NULL, 'V'},
+	{"no-workaround", no_argument, NULL, 'W'},
 	{"no-xattr", no_argument, NULL, 'X'},
 	{0, 0, 0, 0}
       };
       c =
-	getopt_long (argc, argv, "c:C:d:hL:mn:o:pvr:s:S:t:T:VX",
+	getopt_long (argc, argv, "c:C:d:hL:mn:o:pvr:s:S:t:T:VWX",
 		     long_options, NULL);
       if (c == -1)
 	break;
@@ -217,6 +219,9 @@ parseopts (int argc, char **restrict argv, struct law *restrict l)
 	case 'V':
 	  show_version ();
 	  exit (0);
+	case 'W':
+	  l->workaround = false;
+	  break;
 	case 'X':
 	  l->xattr = 0;
 	  break;
